@@ -5,8 +5,10 @@
 
 #include "common/mimetypes.h"
 
+#include <QLockFile>
 #include <QObject>
 #include <QPersistentModelIndex>
+#include <QSet>
 #include <QStringList>
 #include <QTimer>
 #include <QVector>
@@ -18,7 +20,7 @@ struct Ext;
 struct BaseNameExtensions;
 
 #define COPYQ_MIME_PREFIX_ITEMSYNC COPYQ_MIME_PREFIX "itemsync-"
-#define COPYQ_MIME_PREFIX_ITEMSYNC_PRIVATE COPYQ_MIME_PREFIX "itemsync-private-"
+#define COPYQ_MIME_PREFIX_ITEMSYNC_PRIVATE COPYQ_MIME_PRIVATE_PREFIX "itemsync-"
 extern const QLatin1String mimeExtensionMap;
 extern const QLatin1String mimeBaseName;
 extern const QLatin1String mimeNoSave;
@@ -26,10 +28,15 @@ extern const QLatin1String mimeSyncPath;
 extern const QLatin1String mimeNoFormat;
 extern const QLatin1String mimeUnknownFormats;
 
-extern const QLatin1String mimePrivatePrefix;
+extern const QLatin1String mimePrivateSyncPrefix;
 extern const QLatin1String mimeOldBaseName;
 extern const QLatin1String mimeHashPrefix;
 
+enum class UpdateType {
+    Inserted,
+    Changed,
+};
+
 struct FileFormat {
     bool isValid() const { return !extensions.isEmpty(); }
     QStringList extensions;
@@ -41,6 +48,11 @@ using BaseNameExtensionsList = QList<BaseNameExtensions>;
 
 using Hash = QByteArray;
 
+class SyncDataFile;
+QDataStream &operator<<(QDataStream &out, SyncDataFile value);
+QDataStream &operator>>(QDataStream &in, SyncDataFile &value);
+void registerSyncDataFileConverter();
+
 class FileWatcher final : public QObject {
 public:
     static QString getBaseName(const QModelIndex &index);
@@ -56,8 +68,15 @@ public:
 
     static Hash calculateHash(const QByteArray &bytes);
 
-    FileWatcher(const QString &path, const QStringList &paths, QAbstractItemModel *model,
-                int maxItems, const QList<FileFormat> &formatSettings, QObject *parent = nullptr);
+    FileWatcher(
+        const QString &path,
+        const QStringList &paths,
+        QAbstractItemModel *model,
+        int maxItems,
+        const QList<FileFormat> &formatSettings,
+        int itemDataThreshold,
+        QObject *parent = nullptr
+    );
 
     const QString &path() const { return m_path; }
 
@@ -98,18 +117,23 @@ private:
 
     QList<QPersistentModelIndex> indexList(int first, int last);
 
-    void saveItems(int first, int last);
+    void saveItems(int first, int last, UpdateType updateType);
 
-    bool renameMoveCopy(const QDir &dir, const QList<QPersistentModelIndex> &indexList);
+    bool renameMoveCopy(
+        const QDir &dir, const QList<QPersistentModelIndex> &indexList, UpdateType updateType);
 
     void updateDataAndWatchFile(
             const QDir &dir, const BaseNameExtensions &baseNameWithExts,
             QVariantMap *dataMap, QVariantMap *mimeToExtension);
 
-    bool copyFilesFromUriList(const QByteArray &uriData, int targetRow, const QStringList &baseNames);
+    bool copyFilesFromUriList(const QByteArray &uriData, int targetRow, const QSet<QString> &baseNames);
+
+    void updateMovedRows();
 
     QAbstractItemModel *m_model;
     QTimer m_updateTimer;
+    QTimer m_moveTimer;
+    int m_moveEnd = -1;
     int m_interval = 0;
     const QList<FileFormat> &m_formatSettings;
     QString m_path;
@@ -121,6 +145,9 @@ private:
     QList<QPersistentModelIndex> m_batchIndexData;
     BaseNameExtensionsList m_fileList;
     int m_lastBatchIndex = -1;
+    int m_itemDataThreshold = -1;
+
+    QLockFile m_lock;
 };
 
 #endif // FILEWATCHER_H
