@@ -22,30 +22,15 @@ namespace {
 
 bool hasSameData(const QVariantMap &data, const QVariantMap &lastData)
 {
-    // Detect change also in case the data is unchanged but previously copied
-    // by CopyQ and now externally. This solves storing a copied text which was
-    // previously synchronized from selection to clipboard via CopyQ.
-    if (
-            !lastData.value(mimeOwner).toByteArray().isEmpty()
-            && data.value(mimeOwner).toByteArray().isEmpty()
-       )
-    {
-        return false;
-    }
-
     for (auto it = lastData.constBegin(); it != lastData.constEnd(); ++it) {
         const auto &format = it.key();
-        if ( !format.startsWith(COPYQ_MIME_PREFIX)
-             && !data.contains(format) )
-        {
+        if ( !data.contains(format) )
             return false;
-        }
     }
 
     for (auto it = data.constBegin(); it != data.constEnd(); ++it) {
         const auto &format = it.key();
-        if ( !format.startsWith(COPYQ_MIME_PREFIX)
-             && !data[format].toByteArray().isEmpty()
+        if ( !data[format].toByteArray().isEmpty()
              && data[format] != lastData.value(format) )
         {
             return false;
@@ -60,6 +45,11 @@ bool isClipboardDataHidden(const QVariantMap &data)
     return data.value(mimeHidden).toByteArray() == "1";
 }
 
+bool isClipboardDataSecret(const QVariantMap &data)
+{
+    return data.value(mimeSecret).toByteArray() == "1";
+}
+
 int defaultOwnerUpdateInterval()
 {
 #ifdef COPYQ_WS_X11
@@ -84,7 +74,7 @@ ClipboardMonitor::ClipboardMonitor(const QStringList &formats)
     m_ownerMonitor.setUpdateInterval(
         ownerUpdateInterval < 0 ? defaultOwnerUpdateInterval() : ownerUpdateInterval);
 
-    m_formats.append({mimeOwner, mimeWindowTitle, mimeItemNotes, mimeHidden});
+    m_formats.append({mimeOwner, mimeWindowTitle, mimeItemNotes, mimeHidden, mimeSecret});
     m_formats.removeDuplicates();
 
     connect( m_clipboard.get(), &PlatformClipboard::changed,
@@ -94,7 +84,8 @@ ClipboardMonitor::ClipboardMonitor(const QStringList &formats)
     m_storeSelection = config.option<Config::check_selection>();
     m_runSelection = config.option<Config::run_selection>();
 
-    m_clipboardToSelection = config.option<Config::copy_clipboard>();
+    m_clipboardToSelection = config.option<Config::copy_clipboard>()
+        && m_clipboard->isSelectionSupported();
     m_selectionToClipboard = config.option<Config::copy_selection>();
 
     if (!m_storeSelection && !m_runSelection && !m_selectionToClipboard) {
@@ -137,19 +128,15 @@ void ClipboardMonitor::onClipboardChanged(ClipboardMode mode)
     auto clipboardData = mode == ClipboardMode::Clipboard
             ? &m_clipboardData : &m_selectionData;
 
-    if ( hasSameData(data, *clipboardData) ) {
+    const bool isDataUnchanged = hasSameData(data, *clipboardData);
+    if (!isDataUnchanged) {
+        *clipboardData = data;
 #ifdef HAS_MOUSE_SELECTIONS
-        if ( !m_runSelection && mode == ClipboardMode::Selection )
-            return;
-#endif
-        COPYQ_LOG( QString("Ignoring unchanged %1")
-                   .arg(mode == ClipboardMode::Clipboard ? "clipboard" : "selection") );
-        emit clipboardUnchanged(data);
+    } else if (isDataUnchanged && !m_runSelection && mode == ClipboardMode::Selection) {
         return;
+#endif
     }
 
-    *clipboardData = data;
-
     if ( !data.contains(mimeOwner)
         && !data.contains(mimeWindowTitle)
         && !m_clipboardOwner.isEmpty() )
@@ -157,13 +144,31 @@ void ClipboardMonitor::onClipboardChanged(ClipboardMode mode)
             data.insert(mimeWindowTitle, m_clipboardOwner.toUtf8());
     }
 
-    COPYQ_LOG( QString("%1 changed, owner is \"%2\"")
-               .arg(mode == ClipboardMode::Clipboard ? "Clipboard" : "Selection",
+    COPYQ_LOG( QStringLiteral("%1 changed, owner is: %2")
+               .arg(QLatin1String(mode == ClipboardMode::Clipboard ? "Clipboard" : "Selection"),
                     getTextData(data, mimeOwner)) );
 
+    const auto defaultTab = m_clipboardTab.isEmpty() ? defaultClipboardTabName() : m_clipboardTab;
+    setTextData(&data, defaultTab, mimeCurrentTab);
+
+#ifdef HAS_MOUSE_SELECTIONS
+    if (mode == ClipboardMode::Selection)
+        data.insert(mimeClipboardMode, QByteArrayLiteral("selection"));
+
+    if (mode == ClipboardMode::Clipboard ? m_storeClipboard : m_storeSelection) {
+#else
+    if (m_storeClipboard) {
+#endif
+        setTextData(&data, m_clipboardTab, mimeOutputTab);
+    }
+
+    if (isDataUnchanged) {
+        emit clipboardUnchanged(data);
+        return;
+    }
+
 #ifdef HAS_MOUSE_SELECTIONS
     if ( (mode == ClipboardMode::Clipboard ? m_clipboardToSelection : m_selectionToClipboard)
-        && m_clipboard->isSelectionSupported()
         && !data.contains(mimeOwner) )
     {
         const auto text = getTextData(data);
@@ -180,40 +185,20 @@ void ClipboardMonitor::onClipboardChanged(ClipboardMode mode)
 
     // omit running run automatic commands when disabled
     if ( !m_runSelection && mode == ClipboardMode::Selection ) {
-        if ( m_storeSelection && !m_clipboardTab.isEmpty() ) {
-            data.insert(mimeClipboardMode, QByteArrayLiteral("selection"));
-            setTextData(&data, m_clipboardTab, mimeOutputTab);
+        if ( m_storeSelection && !m_clipboardTab.isEmpty() && !isClipboardDataSecret(data) )
             emit saveData(data);
-        }
         return;
     }
 #endif
 
-    if (mode != ClipboardMode::Clipboard) {
-        const QString modeName = mode == ClipboardMode::Selection
-                ? QStringLiteral("selection")
-                : QStringLiteral("find buffer");
-        data.insert(mimeClipboardMode, modeName);
-    }
-
-    // run automatic commands
-    if ( anySessionOwnsClipboardData(data) ) {
-        emit clipboardChanged(data, ClipboardOwnership::Own);
+    // run script callbacks
+    if ( isClipboardDataSecret(data) ) {
+        emit secretClipboardChanged(data);
     } else if ( isClipboardDataHidden(data) ) {
-        emit clipboardChanged(data, ClipboardOwnership::Hidden);
+        emit hiddenClipboardChanged(data);
+    } else if ( anySessionOwnsClipboardData(data) ) {
+        emit ownClipboardChanged(data);
     } else {
-        const auto defaultTab = m_clipboardTab.isEmpty() ? defaultClipboardTabName() : m_clipboardTab;
-        setTextData(&data, defaultTab, mimeCurrentTab);
-
-
-#ifdef HAS_MOUSE_SELECTIONS
-        if (mode == ClipboardMode::Clipboard ? m_storeClipboard : m_storeSelection) {
-#else
-        if (m_storeClipboard) {
-#endif
-            setTextData(&data, m_clipboardTab, mimeOutputTab);
-        }
-
-        emit clipboardChanged(data, ClipboardOwnership::Foreign);
+        emit clipboardChanged(data);
     }
 }
