@@ -23,6 +23,7 @@
 #include "gui/notificationbutton.h"
 #include "gui/notificationdaemon.h"
 #include "item/itemfactory.h"
+#include "item/itemstore.h"
 #include "item/serialize.h"
 #include "scriptable/scriptableproxy.h"
 
@@ -38,10 +39,10 @@
 #include <QStyleFactory>
 #include <QTextEdit>
 
-#ifdef NO_GLOBAL_SHORTCUTS
-class QxtGlobalShortcut final {};
-#else
+#ifdef COPYQ_GLOBAL_SHORTCUTS
 #include "../qxt/qxtglobalshortcut.h"
+#else
+class QxtGlobalShortcut final {};
 #endif
 
 #include <memory>
@@ -92,17 +93,14 @@ ClipboardServer::ClipboardServer(QApplication *app, const QString &sessionName)
 {
     setLogLabel("Server");
 
-    const QString serverName = clipboardServerName();
-    m_server = new Server(serverName, this);
+    m_server = new Server(clipboardServerName(), this);
 
     if ( m_server->isListening() ) {
         App::installTranslator();
         qApp->setLayoutDirection(QLocale().textDirection());
-        COPYQ_LOG("Server \"" + serverName + "\" started.");
     } else {
         App::installTranslator();
         if ( canUseStandardOutput() ) {
-            COPYQ_LOG("Server \"" + serverName + "\" already running!");
             log( tr("CopyQ server is already running."), LogWarning );
         }
         exit(0);
@@ -110,10 +108,10 @@ ClipboardServer::ClipboardServer(QApplication *app, const QString &sessionName)
     }
 
     if ( sessionName.isEmpty() ) {
-        QGuiApplication::setApplicationDisplayName("CopyQ");
+        QGuiApplication::setApplicationDisplayName(QStringLiteral("CopyQ"));
     } else {
         QGuiApplication::setApplicationDisplayName(
-            QString::fromLatin1("CopyQ-%1").arg(sessionName));
+            QStringLiteral("CopyQ-%1").arg(sessionName));
     }
 
     QGuiApplication::setDesktopFileName(QStringLiteral("com.github.hluk.copyq"));
@@ -124,6 +122,8 @@ ClipboardServer::ClipboardServer(QApplication *app, const QString &sessionName)
 
     QApplication::setQuitOnLastWindowClosed(false);
 
+    ensureSettingsDirectoryExists();
+
     m_sharedData = std::make_shared<ClipboardBrowserShared>();
     m_sharedData->itemFactory = new ItemFactory(this);
     m_sharedData->notifications = new NotificationDaemon(this);
@@ -163,6 +163,8 @@ ClipboardServer::ClipboardServer(QApplication *app, const QString &sessionName)
     connect( m_wnd, &MainWindow::commandsSaved,
              this, &ClipboardServer::onCommandsSaved );
 
+    m_server->start();
+
     {
         AppConfig appConfig;
         loadSettings(&appConfig);
@@ -173,8 +175,6 @@ ClipboardServer::ClipboardServer(QApplication *app, const QString &sessionName)
 
     qApp->installEventFilter(this);
 
-    m_server->start();
-
     // Ignore global shortcut key presses in any widget.
     m_ignoreKeysTimer.setInterval(100);
     m_ignoreKeysTimer.setSingleShot(true);
@@ -183,14 +183,17 @@ ClipboardServer::ClipboardServer(QApplication *app, const QString &sessionName)
         m_actionDataToSend.clear();
     });
 
+    initSingleShotTimer(&m_timerCleanItemFiles, 120000, this, &ClipboardServer::cleanDataFiles);
+
     initSingleShotTimer(&m_updateThemeTimer, 1000, this, [this](){
         AppConfig appConfig;
         loadSettings(&appConfig);
     });
 
+    setClipboardMonitorRunning(false);
     startMonitoring();
 
-    callback("onStart");
+    callback(QStringLiteral("onStart"));
 }
 
 ClipboardServer::~ClipboardServer()
@@ -216,6 +219,7 @@ void ClipboardServer::stopMonitoring()
         return;
 
     COPYQ_LOG("Terminating monitor");
+    setClipboardMonitorRunning(false);
 
     const auto client = findClient(m_monitor->id());
     if (client)
@@ -230,7 +234,7 @@ void ClipboardServer::startMonitoring()
     COPYQ_LOG("Starting monitor");
 
     m_monitor = new Action();
-    m_monitor->setCommand("copyq --clipboard-access monitorClipboard");
+    m_monitor->setCommand(QStringLiteral("copyq --clipboard-access monitorClipboard"));
     connect( m_monitor.data(), &QObject::destroyed,
              this, &ClipboardServer::onMonitorFinished );
     m_sharedData->actions->internalAction(m_monitor);
@@ -245,7 +249,7 @@ void ClipboardServer::removeGlobalShortcuts()
 
 void ClipboardServer::onCommandsSaved(const QVector<Command> &commands)
 {
-#ifndef NO_GLOBAL_SHORTCUTS
+#ifdef COPYQ_GLOBAL_SHORTCUTS
     removeGlobalShortcuts();
 
     QList<QKeySequence> usedShortcuts;
@@ -282,7 +286,7 @@ void ClipboardServer::onAboutToQuit()
         return;
     m_exitting = true;
 
-    callback("onExit");
+    callback(QStringLiteral("onExit"));
     waitForCallbackToFinish();
 
     m_ignoreNewConnections = true;
@@ -292,6 +296,7 @@ void ClipboardServer::onAboutToQuit()
     terminateClients(5000);
 
     m_wnd->saveTabs();
+    cleanDataFiles();
 }
 
 void ClipboardServer::onCommitData(QSessionManager &sessionManager)
@@ -434,7 +439,7 @@ void ClipboardServer::callback(const QString &scriptFunction)
         return;
 
     waitForCallbackToFinish();
-    COPYQ_LOG( QString("Starting callback: %1").arg(scriptFunction) );
+    COPYQ_LOG( QStringLiteral("Starting callback: %1").arg(scriptFunction) );
     m_callback = new Action();
     m_callback->setCommand(QStringList() << "copyq" << scriptFunction);
     m_sharedData->actions->internalAction(m_callback);
@@ -462,6 +467,12 @@ void ClipboardServer::sendActionData(int actionId, const QByteArray &bytes)
     }
 }
 
+void ClipboardServer::cleanDataFiles()
+{
+    COPYQ_LOG("Cleaning unused item files");
+    ::cleanDataFiles( m_wnd->tabs() );
+}
+
 void ClipboardServer::onClientNewConnection(const ClientSocketPtr &client)
 {
     auto proxy = new ScriptableProxy(m_wnd);
@@ -512,7 +523,7 @@ void ClipboardServer::onClientMessageReceived(
         break;
     }
     default:
-        log(QString("Unhandled command status: %1").arg(messageCode));
+        log(QStringLiteral("Unhandled command status: %1").arg(messageCode));
         break;
     }
 }
@@ -531,6 +542,8 @@ void ClipboardServer::onClientConnectionFailed(ClientSocketId clientId)
 void ClipboardServer::onMonitorFinished()
 {
     COPYQ_LOG("Monitor finished");
+    if (!m_monitor)
+        setClipboardMonitorRunning(false);
     stopMonitoring();
     startMonitoring();
 }
@@ -554,13 +567,13 @@ void ClipboardServer::onNotificationButtonClicked(const NotificationButton &butt
 
 void ClipboardServer::createGlobalShortcut(const QKeySequence &shortcut, const Command &command)
 {
-#ifdef NO_GLOBAL_SHORTCUTS
+#ifndef COPYQ_GLOBAL_SHORTCUTS
     Q_UNUSED(shortcut)
     Q_UNUSED(command)
 #else
     auto s = new QxtGlobalShortcut(shortcut, this);
     if (!s->isValid()) {
-        log(QString("Failed to set global shortcut \"%1\" for command \"%2\".")
+        log(QStringLiteral("Failed to set global shortcut \"%1\" for command \"%2\".")
             .arg(shortcut.toString(),
                  command.name),
             LogWarning);
@@ -628,8 +641,9 @@ bool ClipboardServer::eventFilter(QObject *object, QEvent *ev)
         const auto stateChangeEvent = static_cast<QApplicationStateChangeEvent*>(ev);
         const auto state = stateChangeEvent->applicationState();
         if (state != Qt::ApplicationActive) {
-            COPYQ_LOG( QString("Saving items on application state change (%1)").arg(state) );
+            COPYQ_LOG( QStringLiteral("Saving items on application state change (%1)").arg(state) );
             m_wnd->saveTabs();
+            m_timerCleanItemFiles.start();
         }
     } else if (type == QEvent::ThemeChange) {
         if ( !m_updateThemeTimer.isActive() )
@@ -653,17 +667,17 @@ void ClipboardServer::loadSettings(AppConfig *appConfig)
 
     const QString styleName = appConfig->option<Config::style>();
     if ( !styleName.isEmpty() ) {
-        log( QString("Style: %1").arg(styleName) );
+        log( QStringLiteral("Style: %1").arg(styleName) );
         QStyle *style = QStyleFactory::create(styleName);
         if (style) {
             QApplication::setStyle(style);
         } else {
-            const QString styles = QStyleFactory::keys().join(", ");
-            log( QString("Failed to set style, valid are: %1").arg(styles), LogWarning );
+            const QString styles = QStyleFactory::keys().join(QLatin1String(", "));
+            log( QStringLiteral("Failed to set style, valid are: %1").arg(styles), LogWarning );
         }
     }
 
-    settings.beginGroup("Theme");
+    settings.beginGroup(QStringLiteral("Theme"));
     m_sharedData->theme.loadTheme(settings);
     settings.endGroup();
 
@@ -683,6 +697,8 @@ void ClipboardServer::loadSettings(AppConfig *appConfig)
     m_sharedData->saveDelayMsOnItemEdited = appConfig->option<Config::save_delay_ms_on_item_edited>();
     m_sharedData->rowIndexFromOne = appConfig->option<Config::row_index_from_one>();
 
+    m_sharedData->actions->setMaxRowCount(appConfig->option<Config::max_process_manager_rows>());
+
     m_wnd->loadSettings(settings, appConfig);
 
     m_textTabSize = appConfig->option<Config::text_tab_width>();
@@ -696,7 +712,7 @@ void ClipboardServer::loadSettings(AppConfig *appConfig)
     m_sharedData->notifications->setNativeNotificationsEnabled(
         appConfig->option<Config::native_notifications>() );
     m_sharedData->notifications->setNotificationOpacity(
-        m_sharedData->theme.color("notification_bg").alphaF() );
+        m_sharedData->theme.color(QStringLiteral("notification_bg")).alphaF() );
     m_sharedData->notifications->setNotificationStyleSheet(
         m_sharedData->theme.getNotificationStyleSheet() );
 
@@ -729,7 +745,7 @@ void ClipboardServer::loadSettings(AppConfig *appConfig)
 
 void ClipboardServer::shortcutActivated(QxtGlobalShortcut *shortcut)
 {
-#ifdef NO_GLOBAL_SHORTCUTS
+#ifndef COPYQ_GLOBAL_SHORTCUTS
     Q_UNUSED(shortcut)
 #else
     m_ignoreKeysTimer.start();
