@@ -29,25 +29,25 @@ QString actionDescription(const Action &action)
 {
     const auto name = action.name();
     if ( !name.isEmpty() )
-        return QString::fromLatin1("Command \"%1\"").arg(name);
+        return QStringLiteral("Command \"%1\"").arg(name);
 
     return action.commandLine();
 }
 
-uint maxRowCount()
-{
-    return AppConfig().option<Config::max_process_manager_rows>();
-}
-
 } // namespace
 
 ActionHandler::ActionHandler(NotificationDaemon *notificationDaemon, QObject *parent)
     : QObject(parent)
     , m_notificationDaemon(notificationDaemon)
-    , m_actionModel(new ActionTableModel(maxRowCount(), parent))
+    , m_actionModel(new ActionTableModel(parent))
 {
 }
 
+void ActionHandler::setMaxRowCount(uint rows)
+{
+    m_actionModel->setMaxRowCount(rows);
+}
+
 void ActionHandler::showProcessManagerDialog(QWidget *parent)
 {
     auto dialog = new ActionHandlerDialog(this, m_actionModel, parent);
@@ -98,7 +98,7 @@ void ActionHandler::action(Action *action)
     action->setId(id);
     m_actions.insert(id, action);
 
-    COPYQ_LOG( QString("Executing: %1").arg(actionDescription(*action)) );
+    COPYQ_LOG( QStringLiteral("Executing: %1").arg(actionDescription(*action)) );
     action->start();
 }
 
@@ -120,7 +120,7 @@ void ActionHandler::closeAction(Action *action)
 #ifdef Q_OS_WIN
     // FIXME: Ignore specific exit code for clipboard monitor on Windows when logging out.
     } else if ( action->exitCode() == 1073807364 ) {
-        COPYQ_LOG( QString("Exit code %1 (on logout?) with command: %2")
+        COPYQ_LOG( QStringLiteral("Exit code %1 (on logout?) with command: %2")
                    .arg(action->exitCode())
                    .arg(action->commandLine()) );
 #endif
@@ -151,9 +151,9 @@ void ActionHandler::showActionErrors(Action *action, const QString &message, ush
     const int maxWidthPoints =
             AppConfig().option<Config::notification_maximum_width>();
     const QString command = action->commandLine()
-            .replace("copyq eval --", "copyq:");
+            .replace(QLatin1String("copyq eval --"), QLatin1String("copyq:"));
     const QString name = action->name().isEmpty()
-            ? QString(command).replace('\n', " ")
+            ? QString(command).replace('\n', QLatin1String(" "))
             : action->name();
     const QString format = tr("Command %1").arg(quoteString("%1"));
     const QString title = elideText(name, QFont(), format, pointsToPixels(maxWidthPoints));
@@ -163,9 +163,9 @@ void ActionHandler::showActionErrors(Action *action, const QString &message, ush
     const auto lines = command.split("\n");
     const auto lineNumberWidth = static_cast<int>(std::log10(lines.size())) + 1;
     for (const auto &line : lines)
-        msg.append(QString::fromLatin1("\n%1. %2").arg(++lineNumber, lineNumberWidth).arg(line));
+        msg.append(QStringLiteral("\n%1. %2").arg(++lineNumber, lineNumberWidth).arg(line));
 
-    log(title + "\n" + msg);
+    log(QStringLiteral("%1\n%2").arg(title, msg));
 
     auto notification = m_notificationDaemon->createNotification(notificationId);
     notification->setTitle(title);
