@@ -208,19 +208,13 @@ bool MacPlatform::findPluginDir(QDir *pluginsDir)
 {
     pluginsDir->setPath( qApp->applicationDirPath() );
     if (pluginsDir->dirName() != "MacOS") {
-        if ( pluginsDir->cd("plugins")) {
-            COPYQ_LOG("Found plugins in build tree");
-            return true;
-        }
-        return false;
+        return pluginsDir->cd("plugins");
     }
 
     if ( pluginsDir->cdUp() // Contents
             && pluginsDir->cd("PlugIns")
             && pluginsDir->cd("copyq"))
     {
-        // OK, found it in the bundle
-        COPYQ_LOG("Found plugins in application bundle");
         return true;
     }
 
@@ -229,8 +223,8 @@ bool MacPlatform::findPluginDir(QDir *pluginsDir)
     if ( pluginsDir->cdUp() // Contents
             && pluginsDir->cdUp() // copyq.app
             && pluginsDir->cdUp() // repo root
-            && pluginsDir->cd("plugins")) {
-        COPYQ_LOG("Found plugins in build tree");
+            && pluginsDir->cd("plugins"))
+    {
         return true;
     }
 
