@@ -1232,38 +1232,6 @@ void ScriptableProxy::runInternalAction(const QVariantMap &data, const QString &
     m_wnd->runInternalAction(action);
 }
 
-QByteArray ScriptableProxy::tryGetCommandOutput(const QString &command)
-{
-    INVOKE(tryGetCommandOutput, (command));
-
-    for (int i = 0; i < 3; ++i) {
-        Action action;
-        action.setCommand(command);
-        action.setReadOutput(true);
-
-        QByteArray output;
-        connect( &action, &Action::actionOutput,
-                 this, [&output](const QByteArray &actionOutput) {
-                     output.append(actionOutput);
-                 } );
-
-        action.start();
-        if ( !action.waitForFinished(5000) ) {
-            if ( output.isEmpty() || !action.waitForFinished(30000) ) {
-                action.terminate();
-                continue;
-            }
-        }
-
-        if ( action.actionFailed() || action.exitCode() != 0 )
-            continue;
-
-        return output;
-    }
-
-    return QByteArray();
-}
-
 void ScriptableProxy::showMessage(const QString &title,
         const QString &msg,
         const QString &icon,
