@@ -247,6 +247,8 @@ private slots:
     void automaticCommandStoreSpecialFormat();
     void automaticCommandIgnoreSpecialFormat();
 
+    void globalCommandInMenu();
+
     void scriptCommandLoaded();
     void scriptCommandAddFunction();
     void scriptCommandOverrideFunction();
@@ -306,6 +308,7 @@ private slots:
     void startServerAndRunCommand();
 
     void avoidStoringPasswords();
+    void scriptsForPasswords();
 
     void currentClipboardOwner();
 
